@@ -56,7 +56,7 @@
 enum {
   ARG_0,
   ARG_HANDLE_SIZE,
-  ARG_QUANTUM
+  ARG_QUANTUM,
 };
 
 static void    e_paned_class_init (EPanedClass  *klass);
@@ -134,7 +134,10 @@ e_paned_class_init (EPanedClass *klass)
   widget_class->map = e_paned_map;
   widget_class->unmap = e_paned_unmap;
   widget_class->unrealize = e_paned_unrealize;
+#warning removed expose
+#if 0
   widget_class->expose_event = e_paned_expose;
+#endif
   widget_class->style_set = e_paned_style_set;
 
   container_class->add = e_paned_add;
@@ -362,9 +365,11 @@ e_paned_unrealize (GtkWidget *widget)
     (* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
 }
 
+#warning FIXME: badly broken
+#if 0
 static gint
 e_paned_expose (GtkWidget      *widget,
-		  GdkEventExpose *event)
+		GdkEventExpose *event)
 {
   EPaned *paned;
   GdkEventExpose child_event;
@@ -404,6 +409,7 @@ e_paned_expose (GtkWidget      *widget,
 
   return FALSE;
 }
+#endif
 
 void
 e_paned_add1 (EPaned  *paned,
@@ -654,7 +660,7 @@ e_paned_compute_position(EPaned *paned,
 gboolean
 e_paned_handle_shown(EPaned *paned)
 {
-  EPanedClass *klass = E_PANED_CLASS(GTK_OBJECT(paned)->klass);
+  EPanedClass *klass = E_PANED_CLASS(GTK_OBJECT_GET_CLASS(paned));
 
   if (klass->handle_shown)
     return (*klass->handle_shown)(paned);
