@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-tree-table-adapter.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -26,8 +26,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtksignal.h>
-#include <tree.h>
-#include <parser.h>
+#include <libxml/tree.h>
+#include <libxml/parser.h>
 #include "gal/util/e-util.h"
 #include "gal/util/e-xml-utils.h"
 #include "e-tree-table-adapter.h"
@@ -384,6 +384,11 @@ etta_destroy (GtkObject *object)
 {
 	ETreeTableAdapter *etta = E_TREE_TABLE_ADAPTER (object);
 
+	if (!etta->priv) {
+		GTK_OBJECT_CLASS (parent_class)->destroy (object);
+		return;
+	}
+
 	if (etta->priv->source && e_tree_model_has_save_id(etta->priv->source)) {
 		g_hash_table_foreach(etta->priv->attributes, free_string, NULL);
 	}
@@ -420,6 +425,7 @@ etta_destroy (GtkObject *object)
 	g_free (etta->priv->map_table);
 
 	g_free (etta->priv);
+	etta->priv = NULL;
 
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
@@ -608,16 +614,16 @@ etta_class_init (ETreeTableAdapterClass *klass)
 static void
 etta_init (ETreeTableAdapter *etta)
 {
-	etta->priv                                  = g_new(ETreeTableAdapterPriv, 1);
+	etta->priv = g_new(ETreeTableAdapterPriv, 1);
 
 	etta->priv->source                          = NULL;
 
-	etta->priv->n_map                           = 0;
-	etta->priv->n_vals_allocated                = 0;
+	etta->priv->n_map = 0;
+	etta->priv->n_vals_allocated = 0;
 	etta->priv->map_table                       = NULL;
 	etta->priv->attributes                      = NULL;
 
-	etta->priv->root_visible                    = TRUE;
+	etta->priv->root_visible = TRUE;
 
 	etta->priv->last_access                     = 0;
 
