@@ -1,21 +1,34 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
+ * gal-define-views-model.c
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Author:
- *   Christopher James Lahey <clahey@helixcode.com>
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
  *
- * (C) 1999 Helix Code, Inc.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 #include <config.h>
+#include <libxml/tree.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include "gal-define-views-model.h"
-#include <gnome-xml/tree.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
-#include <gnome.h>
 
 #define PARENT_TYPE e_table_model_get_type()
-ETableModelClass *parent_class;
+static ETableModelClass *parent_class;
 
 /*
  * GalDefineViewsModel callbacks
@@ -36,7 +49,12 @@ gdvm_destroy(GtkObject *object)
 {
 	GalDefineViewsModel *model = GAL_DEFINE_VIEWS_MODEL(object);
 
-	gtk_object_unref(GTK_OBJECT(model->collection));
+	if (model->collection)
+		gtk_object_unref(GTK_OBJECT(model->collection));
+	model->collection = NULL;
+
+	if (GTK_OBJECT_CLASS (parent_class)->destroy)
+		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 /* This function returns the number of columns in our ETableModel. */
@@ -75,6 +93,7 @@ gdvm_set_value_at (ETableModel *etc, int col, int row, const void *val)
 {
 	GalDefineViewsModel *views = GAL_DEFINE_VIEWS_MODEL(etc);
 	if (views->editable) {
+		e_table_model_pre_change(etc);
 		gal_view_set_title(gal_view_collection_get_view(views->collection, row), val);
 		e_table_model_cell_changed(etc, col, row);
 	}
@@ -192,6 +211,7 @@ gal_define_views_model_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 		break;
 
 	case ARG_COLLECTION:
+		e_table_model_pre_change(E_TABLE_MODEL(o));
 		if (GTK_VALUE_OBJECT (*arg))
 			model->collection = GAL_VIEW_COLLECTION(GTK_VALUE_OBJECT (*arg));
 		else
@@ -311,6 +331,7 @@ gal_define_views_model_copy_view (GalDefineViewsModel *model,
 				  int n)
 {
 	ETableModel *etm = E_TABLE_MODEL(model);
+	e_table_model_pre_change(etm);
 	gal_view_collection_copy_view(model->collection, n);
 	e_table_model_row_inserted(etm, gal_view_collection_get_count(model->collection) - 1);
 }
