@@ -23,7 +23,6 @@
 
 #include <config.h>
 #include "e-util.h"
-#include "e-i18n.h"
 
 #include <glib.h>
 #include <gtk/gtkobject.h>
@@ -37,48 +36,33 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-#include <libgnome/gnome-util.h>
-#include <math.h>
 
 #if 0
 #include <libgnomevfs/gnome-vfs.h>
 #endif
 
 int
-g_str_compare (const void *x, const void *y)
+g_str_compare(const void *x, const void *y)
 {
 	if (x == NULL || y == NULL) {
 		if (x == y)
 			return 0;
 		else
 			return x ? -1 : 1;
-	}
-	
-	return strcmp (x, y);
+	} 
+		
+	return strcmp(x, y);
 }
 
 int
-g_collate_compare (const void *x, const void *y)
+g_int_compare(const void *x, const void *y)
 {
-	if (x == NULL || y == NULL) {
-		if (x == y)
-			return 0;
-		else
-			return x ? -1 : 1;
-	}
-	
-	return g_utf8_collate (x, y);
-}
-
-int
-g_int_compare (const void *x, const void *y)
-{
-	if (GPOINTER_TO_INT (x) < GPOINTER_TO_INT (y))
-		return -1;
-	else if (GPOINTER_TO_INT (x) == GPOINTER_TO_INT (y))
-		return 0;
-	else
-		return 1;
+  if ( GPOINTER_TO_INT(x) < GPOINTER_TO_INT(y) )
+    return -1;
+  else if ( GPOINTER_TO_INT(x) == GPOINTER_TO_INT(y) )
+    return 0;
+  else
+    return 1;
 }
 
 char *
@@ -104,7 +88,7 @@ e_free_object_list (GList *list)
 	GList *p;
 
 	for (p = list; p != NULL; p = p->next)
-		g_object_unref (p->data);
+		gtk_object_unref (GTK_OBJECT (p->data));
 
 	g_list_free (list);
 }
@@ -115,7 +99,7 @@ e_free_object_slist (GSList *list)
 	GSList *p;
 
 	for (p = list; p != NULL; p = p->next)
-		g_object_unref (p->data);
+		gtk_object_unref (GTK_OBJECT (p->data));
 
 	g_slist_free (list);
 }
@@ -198,7 +182,7 @@ e_write_file(const char *filename, const char *data, int flags)
 	int fd;
 	int length = strlen(data);
 	int bytes;
-	fd = open(filename, flags | O_WRONLY, 0666);
+	fd = open(filename, flags, 0666);
 	if (fd == -1)
 		return errno;
 	while (length > 0) {
@@ -237,7 +221,7 @@ e_write_file_mkstemp(char *filename, const char *data)
 		} else {
 			if (errno != EINTR && errno != EAGAIN) {
 				int save_errno = errno;
-				close(fd);
+	close(fd);
 				return save_errno;
 			}
 		}
@@ -264,13 +248,7 @@ e_mkdir_hier(const char *path, mode_t mode)
 {
 	char *copy, *p;
 
-	if (path[0] == '/') {
-		p = copy = g_strdup (path);
-	} else {
-		gchar *current_dir = g_get_current_dir();
-		p = copy = g_concat_dir_and_file (current_dir, path);
-	}
-
+	p = copy = g_strdup (path);
 	do {
 		p = strchr (p + 1, '/');
 		if (p)
@@ -337,6 +315,7 @@ e_read_uri(const char *uri)
 #include "e-marshal.h"
 #include "e-marshal.c"
 
+
 gchar**
 e_strsplit (const gchar *string,
 	    const gchar *delimiter,
@@ -414,7 +393,6 @@ e_strstrcase (const gchar *haystack, const gchar *needle)
 	return NULL;
 }
 
-/* This only makes a filename safe for usage as a filename.  It still may have shell meta-characters in it. */
 void
 e_filename_make_safe (gchar *string)
 {
@@ -423,7 +401,7 @@ e_filename_make_safe (gchar *string)
 	g_return_if_fail (string != NULL);
 	
 	for (p = string; *p; p++) {
-		if (!isprint ((unsigned char)*p) || strchr (" /'\"`&();|<>$%{}!", *p))
+		if (!isprint ((unsigned char)*p) || strchr (" /'\"`&();|<>${}!", *p))
 			*p = '_';
 	}
 }
@@ -500,97 +478,10 @@ e_format_number (gint number)
 	}
 }
 
-static gchar *
-do_format_number_as_float (double number)
-{
-	GList *iterator, *list = NULL;
-	struct lconv *locality;
-	gint char_length = 0;
-	gint group_count = 0;
-	guchar *grouping;
-	int last_count = 3;
-	int divider;
-	char *value;
-	char *value_iterator;
-	double fractional;
-
-	locality = localeconv();
-	grouping = locality->grouping;
-	while (number >= 1.0) {
-		char *group;
-		switch (*grouping) {
-		default:
-			last_count = *grouping;
-			grouping++;
-			/* Fall through */
-		case 0:
-			divider = epow10(last_count);
-			number /= divider;
-			fractional = modf (number, &number);
-			fractional *= divider;
-			fractional = floor (fractional);
-
-			if (number >= 1.0) {
-				group = g_strdup_printf("%0*d", last_count, (int) fractional);
-			} else {
-				group = g_strdup_printf("%d", (int) fractional);
-			}
-			break;
-		case CHAR_MAX:
-			divider = epow10(last_count);
-			number /= divider;
-			fractional = modf (number, &number);
-			fractional *= divider;
-			fractional = floor (fractional);
-
-			while (number >= 1.0) {
-				group = g_strdup_printf("%0*d", last_count, (int) fractional);
-
-				char_length += strlen(group);
-				list = g_list_prepend(list, group);
-				group_count ++;
-
-				divider = epow10(last_count);
-				number /= divider;
-				fractional = modf (number, &number);
-				fractional *= divider;
-				fractional = floor (fractional);
-			}
-
-			group = g_strdup_printf("%d", (int) fractional);
-			break;
-		}
-		char_length += strlen(group);
-		list = g_list_prepend(list, group);
-		group_count ++;
-	}
-
-	if (list) {
-		value = g_new(char, 1 + char_length + (group_count - 1) * strlen(locality->thousands_sep));
-
-		iterator = list;
-		value_iterator = value;
-
-		strcpy(value_iterator, iterator->data);
-		value_iterator += strlen(iterator->data);
-		for (iterator = iterator->next; iterator; iterator = iterator->next) {
-			strcpy(value_iterator, locality->thousands_sep);
-			value_iterator += strlen(locality->thousands_sep);
-
-			strcpy(value_iterator, iterator->data);
-			value_iterator += strlen(iterator->data);
-		}
-		e_free_string_list (list);
-		return value;
-	} else {
-		return g_strdup("0");
-	}
-}
-
 gchar *
 e_format_number_float (gfloat number)
 {
-	gfloat          int_part;
+	gint            int_part;
 	gint            fraction;
 	struct lconv   *locality;
 	gchar          *str_intpart;
@@ -600,8 +491,8 @@ e_format_number_float (gfloat number)
 
 	locality = localeconv();
 	
-	int_part = floor (number);
-	str_intpart = do_format_number_as_float ((double) int_part);
+	int_part = (int) number;
+	str_intpart = e_format_number (int_part);
 
 	if (!strcmp(locality->mon_decimal_point, "")) {
 		decimal_point = ".";
@@ -614,7 +505,8 @@ e_format_number_float (gfloat number)
 
 	if (fraction == 0) {
 		str_fraction = g_strdup ("00");
-	} else {
+	}
+	else {
 		str_fraction = g_strdup_printf ("%02d", fraction);
 	}
 
@@ -629,11 +521,63 @@ e_format_number_float (gfloat number)
 gboolean
 e_create_directory (gchar *directory)
 {
-	gint ret_val = e_mkdir_hier (directory, 0777);
-	if (ret_val == -1)
-		return FALSE;
-	else
-		return TRUE;
+	gchar *full_name;
+	gchar *position;
+	gchar *current_dir = g_get_current_dir();
+	struct stat info;
+	gboolean return_value = TRUE;
+
+	if (directory[0] == '/') {
+		full_name = g_malloc0 (strlen (directory) + 1);
+		strcpy (full_name, directory);
+	} else {
+		full_name = g_malloc0 (strlen (directory) + strlen (current_dir) + 2);
+		sprintf (full_name, "%s/%s", current_dir, directory);
+	}
+
+	if ((position = strrchr (full_name, '/')) == full_name) {
+		if (stat (full_name, &info)) {
+			switch (errno) {
+			case ENOENT:
+				if (mkdir (full_name, 0777)) {
+					switch (errno) {
+					default:
+						return_value = FALSE;
+						break;
+					}
+				}
+				break;
+			default:
+				return_value = FALSE;
+				break;
+			}
+		}
+	} else {
+		*position = 0;
+		e_create_directory (full_name);
+		*position = '/';
+		if (stat (full_name, &info)) {
+			switch (errno) {
+			case ENOENT:
+				if (mkdir (full_name, 0777)) {
+					switch (errno) {
+					default:
+						return_value = FALSE;
+						break;
+					}
+				}
+				break;
+			default:
+				return_value = FALSE;
+				break;
+			}
+		}
+	}
+
+	g_free (current_dir);
+	g_free (full_name);
+
+	return (return_value);
 }
 
 
@@ -768,42 +712,6 @@ size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 #endif
 }
 
-size_t 
-e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
-{
-	size_t sz, ret;
-	char *locale_fmt, *buf;
-
-	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
-	if (!locale_fmt)
-		return 0;
-
-	ret = e_strftime(s, max, locale_fmt, tm);
-	if (!ret) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
-	if (!buf) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	if (sz >= max) {
-		char *tmp = buf + max - 1;
-		tmp = g_utf8_find_prev_char(buf, tmp);
-		if (tmp)
-			sz = tmp - buf;
-		else
-			sz = 0;
-	}
-	memcpy(s, buf, sz);
-	s[sz] = '\0';
-	g_free(locale_fmt);
-	g_free(buf);
-	return sz;
-}
 
 /**
  * Function to do a last minute fixup of the AM/PM stuff if the locale
@@ -866,43 +774,6 @@ size_t e_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct t
 	return(ret);
 }
 
-size_t 
-e_utf8_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct tm *tm)
-{
-	size_t sz, ret;
-	char *locale_fmt, *buf;
-
-	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
-	if (!locale_fmt)
-		return 0;
-
-	ret = e_strftime_fix_am_pm(s, max, locale_fmt, tm);
-	if (!ret) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
-	if (!buf) {
-		g_free (locale_fmt);
-		return 0;
-	}
-
-	if (sz >= max) {
-		char *tmp = buf + max - 1;
-		tmp = g_utf8_find_prev_char(buf, tmp);
-		if (tmp)
-			sz = tmp - buf;
-		else
-			sz = 0;
-	}
-	memcpy(s, buf, sz);
-	s[sz] = '\0';
-	g_free(locale_fmt);
-	g_free(buf);
-	return sz;
-}
-
 /**
  * e_flexible_strtod:
  * @nptr:    the string to convert to a numeric value.
@@ -1180,44 +1051,3 @@ e_strdup_append_strings (gchar *first_string, ...)
 
 	return buffer;
 }
-
-gchar **
-e_strdupv (const gchar **str_array)
-{
-	if (str_array) {
-		gint i;
-		gchar **retval;
-
-		i = 0;
-		while (str_array[i])
-			i++;
-          
-		retval = g_new (gchar*, i + 1);
-
-		i = 0;
-		while (str_array[i]) {
-			retval[i] = g_strdup (str_array[i]);
-			i++;
-		}
-		retval[i] = NULL;
-
-		return retval;
-	} else {
-		return NULL;
-	}
-}
-
-char *
-e_gettext (const char *msgid)
-{
-	static gboolean initialized = FALSE;
-
-	if (!initialized) {
-		bindtextdomain (E_I18N_DOMAIN, GNOMELOCALEDIR);
-		bind_textdomain_codeset (E_I18N_DOMAIN, "UTF-8");
-		initialized = TRUE;
-	}        
-
-	return dgettext (E_I18N_DOMAIN, msgid);
-}
-
