@@ -24,12 +24,10 @@
 #ifndef __E_XML_UTILS__
 #define __E_XML_UTILS__
 
-#include <libgnome/gnome-defs.h>
 #include <glib.h>
+#include <libxml/tree.h>
 
-#include <tree.h>
-
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 xmlNode *e_xml_get_child_by_name                     (const xmlNode *parent,
                                                       const xmlChar *child_name);
@@ -96,6 +94,6 @@ void      e_xml_set_string_prop_by_name              (xmlNode       *parent,
 gchar    *e_xml_get_translated_string_prop_by_name   (const xmlNode *parent,
                                                       const xmlChar *prop_name);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* __E_XML_UTILS__ */
