@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * color-palette.c - A color selector palette
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -31,8 +31,9 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtktable.h>
-#include <libgnomeui/gnome-canvas.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
+#include <libgnomecanvas/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
+#include <gdk/gdkcolor.h>
 #include "gal/util/e-i18n.h"
 #include "gal/util/e-util.h"
 #include "color-group.h"
@@ -48,18 +49,18 @@ enum {
 };
 
 struct _ColorNamePair {
-	char *color;	/* rgb color or otherwise - eg. "rgb:FF/FF/FF" */
+	char *color;	/* rgb color or otherwise - eg. "#FFFFFF" */
 	char *name;	/* english name - eg. "white" */
 };
 
-static guint color_palette_signals [LAST_SIGNAL] = { 0, };
+static gint color_palette_signals [LAST_SIGNAL] = { 0, };
 
-static GtkObjectClass *color_palette_parent_class;
+static GObjectClass *color_palette_parent_class;
 
 #define make_color(P,COL) (((COL) != NULL) ? (COL) : ((P) ? ((P)->default_color) : NULL))
 
 static void
-color_palette_finalize (GtkObject *object)
+color_palette_finalize (GObject *object)
 {
 	ColorPalette *P = COLOR_PALETTE (object);
 
@@ -78,34 +79,12 @@ color_palette_finalize (GtkObject *object)
 	(*color_palette_parent_class->finalize) (object);
 }
 
-
-typedef void (*GtkSignal_NONE__POINTER_BOOL_BOOL) (GtkObject * object,
-						   gpointer arg1,
-						   gboolean arg2,
-						   gboolean arg3,
-						   gpointer user_data);
 static void
-marshal_NONE__POINTER_BOOL_BOOL (GtkObject * object,
-				 GtkSignalFunc func,
-				 gpointer func_data,
-				 GtkArg * args)
-{
-	GtkSignal_NONE__POINTER_BOOL_BOOL rfunc;
-	rfunc = (GtkSignal_NONE__POINTER_BOOL_BOOL) func;
-	(*rfunc) (object,
-		  GTK_VALUE_POINTER (args[0]),
-		  GTK_VALUE_BOOL    (args[1]),
-		  GTK_VALUE_BOOL    (args[2]),
-		  func_data);
-}
-
-
-static void
-color_palette_class_init (GtkObjectClass *object_class)
+color_palette_class_init (GObjectClass *object_class)
 {
 	object_class->finalize = color_palette_finalize;
 
-	color_palette_parent_class = gtk_type_class (gtk_vbox_get_type ());
+	color_palette_parent_class = g_type_class_peek_parent (object_class);
 
 	color_palette_signals [CHANGED] =
 		gtk_signal_new (
@@ -113,7 +92,7 @@ color_palette_class_init (GtkObjectClass *object_class)
 			GTK_RUN_LAST,
 			E_OBJECT_CLASS_TYPE (object_class),
 			GTK_SIGNAL_OFFSET (ColorPaletteClass, changed),
-			marshal_NONE__POINTER_BOOL_BOOL,
+			e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN,
 			GTK_TYPE_NONE, 3, GTK_TYPE_POINTER,
 			GTK_TYPE_BOOL, GTK_TYPE_BOOL);
 
@@ -195,16 +174,16 @@ color_palette_change_custom_color (ColorPalette *P, GdkColor const * const new)
 		item = P->items [index];
 		next_item = P->items [index + 1];
 
-		gtk_object_get (GTK_OBJECT (next_item),
-				"fill_color_gdk", &color,
-				"outline_color_gdk", &outline,
-				NULL);
+		g_object_get (G_OBJECT (next_item),
+			"fill_color_gdk",	&color,
+			"outline_color_gdk",	&outline,
+			NULL);
 		gnome_canvas_item_set (item,
-				       "fill_color_gdk", color,
-				       "outline_color_gdk", outline,
-				       NULL);
-		g_free (color);
-		g_free (outline);
+			"fill_color_gdk",	color,
+			"outline_color_gdk",	outline,
+			NULL);
+		gdk_color_free (color);
+		gdk_color_free (outline);
 	}
 	item = P->items [index];
 	gnome_canvas_item_set (item,
@@ -227,17 +206,14 @@ static void
 cust_color_set (GtkWidget  *color_picker, guint r, guint g, guint b, guint a,
 		ColorPalette *P)
 {
-	GdkColor *c_color;
+	GdkColor c_color;
 
-	c_color = g_new (GdkColor, 1);
+	c_color.red   = (gushort)r;
+	c_color.green = (gushort)g;
+	c_color.blue  = (gushort)b;
 
-	c_color->red   = (gushort)r;
-	c_color->green = (gushort)g;
-	c_color->blue  = (gushort)b;
-
-	e_color_alloc_gdk (c_color);
-	emit_change (P, c_color, TRUE, TRUE);
-	g_free (c_color);
+	e_color_alloc_gdk (NULL, &c_color);
+	emit_change (P, &c_color, TRUE, TRUE);
 }
 
 /*
@@ -247,7 +223,7 @@ cust_color_set (GtkWidget  *color_picker, guint r, guint g, guint b, guint a,
 static void
 cb_nocolor_clicked (GtkWidget *button, ColorPalette *P)
 {
-        emit_change (P, P->default_color, FALSE, TRUE);
+	emit_change (P, P->default_color, FALSE, TRUE);
 }
 
 /*
@@ -270,7 +246,7 @@ color_clicked (GtkWidget *button, ColorPalette *P)
 
 	emit_change (P, gdk_color, FALSE, TRUE);
 
-	g_free (gdk_color);
+	gdk_color_free (gdk_color);
 }
 
 /*
@@ -332,11 +308,7 @@ color_palette_button_new(ColorPalette *P, GtkTable* table,
 	button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
 
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 	canvas = gnome_canvas_new ();
-	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
 
 	gtk_widget_set_usize (canvas, COLOR_PREVIEW_WIDTH, COLOR_PREVIEW_HEIGHT);
 	gtk_container_add (GTK_CONTAINER (button), canvas);
@@ -414,6 +386,9 @@ color_palette_setup (ColorPalette *P,
 	}
 
 	P->tool_tip = tool_tip = gtk_tooltips_new();
+	gtk_object_ref (GTK_OBJECT (P->tool_tip));
+	gtk_object_sink (GTK_OBJECT (P->tool_tip));
+
 	P->custom_color_pos = -1;
 	total = 0;
 
@@ -427,7 +402,7 @@ color_palette_setup (ColorPalette *P,
 			 */
 			if (color_names [pos].color == NULL) {
 				/* This is the default custom color */
-				ColorNamePair color_name  = {"rgb:0/0/0", N_("custom")};
+				ColorNamePair color_name  = {"#000", N_("custom")};
 				row++;
 				if (col == 0 || row < nrows) {
 					/* Add a full row for custom colors */
@@ -565,6 +540,9 @@ color_palette_new_with_vals (char const * const no_color_label,
 	return GTK_WIDGET (P);
 }
 
+/**
+ * color_palette_set_group : absorbs the reference to the group
+ */
 void
 color_palette_set_group (ColorPalette *P, ColorGroup *cg)
 {
@@ -572,92 +550,92 @@ color_palette_set_group (ColorPalette *P, ColorGroup *cg)
 		return;
 
 	if (P->color_group) {
-		gtk_signal_disconnect_by_func (
-			GTK_OBJECT (P->color_group),
-			GTK_SIGNAL_FUNC (cb_group_custom_color_add),
+		g_signal_handlers_disconnect_by_func (
+			G_OBJECT (P->color_group),
+			G_CALLBACK (cb_group_custom_color_add),
 			P);
-		gtk_object_unref(GTK_OBJECT (P->color_group));
+		g_object_unref (G_OBJECT (P->color_group));
 		P->color_group = NULL;
 	}
 	if (cg != NULL) {
 		P->color_group = COLOR_GROUP (cg);
-		gtk_signal_connect (GTK_OBJECT (cg), "custom_color_add",
-			GTK_SIGNAL_FUNC (cb_group_custom_color_add),
+		g_signal_connect (G_OBJECT (cg), "custom_color_add",
+			G_CALLBACK (cb_group_custom_color_add),
 			P);
 
 	}
 }
 
 static ColorNamePair default_color_set [] = {
-	{"rgb:0/0/0", N_("black")},
-	{"rgb:99/33/0", N_("light brown")},
-	{"rgb:33/33/0", N_("brown gold")},
-	{"rgb:0/33/0", N_("dark green #2")},
-	{"rgb:0/33/66", N_("navy")},
-	{"rgb:0/0/80", N_("dark blue")},
-	{"rgb:33/33/99", N_("purple #2")},
-	{"rgb:33/33/33", N_("very dark gray")},
+	{"#000000", N_("black")},
+	{"#993300", N_("light brown")},
+	{"#333300", N_("brown gold")},
+	{"#003300", N_("dark green #2")},
+	{"#003366", N_("navy")},
+	{"#000080", N_("dark blue")},
+	{"#333399", N_("purple #2")},
+	{"#333333", N_("very dark gray")},
 
 
-	{"rgb:80/0/0", N_("dark red")},
-	{"rgb:FF/66/0", N_("red-orange")},
-	{"rgb:80/80/0", N_("gold")},
-	{"rgb:0/80/0", N_("dark green")},
-	{"rgb:0/80/80", N_("dull blue")},
-	{"rgb:0/0/FF", N_("blue")},
-	{"rgb:66/66/99", N_("dull purple")},
-	{"rgb:80/80/80", N_("dark grey")},
+	{"#800000", N_("dark red")},
+	{"#FF6600", N_("red-orange")},
+	{"#808000", N_("gold")},
+	{"#008000", N_("dark green")},
+	{"#008080", N_("dull blue")},
+	{"#0000FF", N_("blue")},
+	{"#666699", N_("dull purple")},
+	{"#808080", N_("dark grey")},
 
 
-	{"rgb:FF/0/0", N_("red")},
-	{"rgb:FF/99/0", N_("orange")},
-	{"rgb:99/CC/0", N_("lime")},
-	{"rgb:33/99/66", N_("dull green")},
-	{"rgb:33/CC/CC",N_("dull blue #2")},
-	{"rgb:33/66/FF", N_("sky blue #2")},
-	{"rgb:80/0/80", N_("purple")},
-	{"rgb:96/96/96", N_("gray")},
+	{"#FF0000", N_("red")},
+	{"#FF9900", N_("orange")},
+	{"#99CC00", N_("lime")},
+	{"#339966", N_("dull green")},
+	{"#33CCCC",N_("dull blue #2")},
+	{"#3366FF", N_("sky blue #2")},
+	{"#800080", N_("purple")},
+	{"#969696", N_("gray")},
 
 
-	{"rgb:FF/0/FF", N_("magenta")},
-	{"rgb:FF/CC/0", N_("bright orange")},
-	{"rgb:FF/FF/0", N_("yellow")},
-	{"rgb:0/FF/0", N_("green")},
-	{"rgb:0/FF/FF", N_("cyan")},
-	{"rgb:0/CC/FF", N_("bright blue")},
-	{"rgb:99/33/66", N_("red purple")},
-	{"rgb:c0/c0/c0", N_("light grey")},
+	{"#FF00FF", N_("magenta")},
+	{"#FFCC00", N_("bright orange")},
+	{"#FFFF00", N_("yellow")},
+	{"#00FF00", N_("green")},
+	{"#00FFFF", N_("cyan")},
+	{"#00CCFF", N_("bright blue")},
+	{"#993366", N_("red purple")},
+	{"#C0C0C0", N_("light grey")},
 
 
-	{"rgb:FF/99/CC", N_("pink")},
-	{"rgb:FF/CC/99", N_("light orange")},
-	{"rgb:FF/FF/99", N_("light yellow")},
-	{"rgb:CC/FF/CC", N_("light green")},
-	{"rgb:CC/FF/FF", N_("light cyan")},
-	{"rgb:99/CC/FF", N_("light blue")},
-	{"rgb:CC/99/FF", N_("light purple")},
-	{"rgb:FF/FF/FF", N_("white")},
+	{"#FF99CC", N_("pink")},
+	{"#FFCC99", N_("light orange")},
+	{"#FFFF99", N_("light yellow")},
+	{"#CCFFCC", N_("light green")},
+	{"#CCFFFF", N_("light cyan")},
+	{"#99CCFF", N_("light blue")},
+	{"#CC99FF", N_("light purple")},
+	{"#FFFFFF", N_("white")},
 
 	/* Disable these for now, they are mostly repeats */
 	{NULL, NULL},
 
-	{"rgb:99/99/FF", N_("purplish blue")},
-	{"rgb:99/33/66", N_("red purple")},
-	{"rgb:FF/FF/CC", N_("light yellow")},
-	{"rgb:CC/FF/FF", N_("light blue")},
-	{"rgb:66/0/66", N_("dark purple")},
-	{"rgb:FF/80/80", N_("pink")},
-	{"rgb:0/66/CC", N_("sky blue")},
-	{"rgb:CC/CC/FF", N_("light purple")},
+	{"#9999FF", N_("purplish blue")},
+	{"#993366", N_("red purple")},
+	{"#FFFFCC", N_("light yellow")},
+	{"#CCFFFF", N_("light blue")},
+	{"#660066", N_("dark purple")},
+	{"#FF8080", N_("pink")},
+	{"#0066CC", N_("sky blue")},
+	{"#CCCCFF", N_("light purple")},
 
-	{"rgb:0/0/80", N_("dark blue")},
-	{"rgb:FF/0/FF", N_("magenta")},
-	{"rgb:FF/FF/0", N_("yellow")},
-	{"rgb:0/FF/FF", N_("cyan")},
-	{"rgb:80/0/80", N_("purple")},
-	{"rgb:80/0/0", N_("dark red")},
-	{"rgb:0/80/80", N_("dull blue")},
-	{"rgb:0/0/FF", N_("blue")},
+	{"#000080", N_("dark blue")},
+	{"#FF00FF", N_("magenta")},
+	{"#FFFF00", N_("yellow")},
+	{"#00FFFF", N_("cyan")},
+	{"#800080", N_("purple")},
+	{"#800000", N_("dark red")},
+	{"#008080", N_("dull blue")},
+	{"#0000FF", N_("blue")},
 
 	{NULL, NULL}
 };
