@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-categories-master-list-dialog-model.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -28,7 +28,7 @@
 #include <gnome.h>
 
 #define PARENT_TYPE e_table_model_get_type()
-static ETableModelClass *parent_class;
+ETableModelClass *parent_class;
 
 /*
  * ECategoriesMasterListDialogModel callbacks
@@ -46,7 +46,7 @@ struct ECategoriesMasterListDialogModelPriv {
 
 enum {
 	ARG_0,
-	ARG_ECML
+	ARG_ECML,
 };
 
 #define COLS (3)
