@@ -1,5 +1,7 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * WidgetColorCombo: A color selector combo box
+ * widget-color-combo.c - A color selector combo box
+ * Copyright 2000, 2001, Ximian, Inc.
  *
  * Authors:
  *   Miguel de Icaza (miguel@kernel.org)
@@ -8,17 +10,35 @@
  * Reworked and split up into a separate ColorPalette object:
  *   Michael Levy (mlevy@genoscope.cns.fr)
  *
+ * And later revised and polished by:
+ *   Almer S. Tigelaar (almer@gnome.org)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
+
 #include <config.h>
 
 #include <gtk/gtkentry.h>
 #include <gtk/gtksignal.h>
-#include <libgnomeui/gnome-canvas.h>
-#include <libgnomeui/gnome-canvas-image.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
-#include <libgnomeui/gnome-preferences.h>
+#include <libgnomecanvas/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas-pixbuf.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
+#include <gal/util/e-util.h>
 #include "e-colors.h"
 #include "widget-color-combo.h"
+#include "gal/util/e-util.h"
 
 enum {
 	CHANGED,
@@ -27,12 +47,12 @@ enum {
 
 static gint color_combo_signals [LAST_SIGNAL] = { 0, };
 
-static GtkObjectClass *color_combo_parent_class;
+static GObjectClass *color_combo_parent_class;
 
 #define make_color(CC,COL) (((COL) != NULL) ? (COL) : ((CC) ? ((CC)->default_color) : NULL))
 
-void
-color_combo_set_color (ColorCombo *cc, GdkColor *color)
+static void
+color_combo_set_color_internal (ColorCombo *cc, GdkColor *color)
 {
 	GdkColor *new_color;
 	GdkColor *outline_color;
@@ -48,13 +68,13 @@ color_combo_set_color (ColorCombo *cc, GdkColor *color)
 }
 
 static void
-color_combo_finalize (GtkObject *object)
+color_combo_finalize (GObject *object)
 {
-	(*color_combo_parent_class->finalize) (object);
+	color_combo_parent_class->finalize (object);
 }
 
 static void
-color_combo_class_init (GtkObjectClass *object_class)
+color_combo_class_init (GObjectClass *object_class)
 {
 	object_class->finalize = color_combo_finalize;
 
@@ -64,12 +84,12 @@ color_combo_class_init (GtkObjectClass *object_class)
 		gtk_signal_new (
 			"changed",
 			GTK_RUN_LAST,
-			object_class->type,
+			E_OBJECT_CLASS_TYPE (object_class),
 			GTK_SIGNAL_OFFSET (ColorComboClass, changed),
-			gtk_marshal_NONE__POINTER,
-			GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+			e_marshal_NONE__POINTER_BOOLEAN,
+			GTK_TYPE_NONE, 2, GTK_TYPE_POINTER, GTK_TYPE_BOOL);
 
-	gtk_object_class_add_signals (object_class, color_combo_signals, LAST_SIGNAL);
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, color_combo_signals, LAST_SIGNAL);
 }
 
 GtkType
@@ -99,28 +119,33 @@ color_combo_get_type (void)
  * Fires signal "changed" with the current color as its param
  */
 static void
-emit_change (ColorCombo *cc, GdkColor *color)
+emit_change (ColorCombo *cc, GdkColor *color, gboolean by_user)
 {
   	gtk_signal_emit (
 		GTK_OBJECT (cc),
 		color_combo_signals [CHANGED],
-		color);
+		color, by_user);
 	gtk_combo_box_popup_hide (GTK_COMBO_BOX (cc));
 }
 
 static void
-cb_color_change (ColorPalette *P, GdkColor *color, gboolean custom, ColorCombo *cc)
+cb_color_change (ColorPalette *P, GdkColor *color,
+		 gboolean custom, gboolean by_user,
+		 ColorCombo *cc)
 {
-	color_combo_set_color (cc, color);
-	emit_change (cc, color);
+	color_combo_set_color_internal (cc, color);
+		
+	emit_change (cc, color, by_user);
 }
 
 static void
 preview_clicked (GtkWidget *button, ColorCombo *cc)
 {
 	GdkColor *color = color_palette_get_current_color (cc->palette);
-	emit_change (cc, color);
-	g_free (color);
+	emit_change (cc, color, TRUE);
+	
+	if (color)
+		gdk_color_free (color);
 }
 
 static void
@@ -133,7 +158,8 @@ cb_cust_color_clicked (GtkWidget *widget, ColorCombo *cc)
  * Creates the color table
  */
 static void
-color_table_setup (ColorCombo *cc, char const * const no_color_label, gchar *group_name)
+color_table_setup (ColorCombo *cc,
+		   char const *no_color_label, ColorGroup *color_group)
 {
 	g_return_if_fail (cc != NULL);
 
@@ -141,7 +167,7 @@ color_table_setup (ColorCombo *cc, char const * const no_color_label, gchar *gro
 	cc->palette = 
 		COLOR_PALETTE (color_palette_new (no_color_label, 
 						  cc->default_color,
-						  group_name));
+						  color_group));
 
 	{
 		GtkWidget *picker = color_palette_get_color_picker (cc->palette);
@@ -161,12 +187,10 @@ color_table_setup (ColorCombo *cc, char const * const no_color_label, gchar *gro
  * Where the actual construction goes on
  */
 static void
-color_combo_construct (ColorCombo *cc, char **icon,
-		       char const * const no_color_label,
-		       gchar *group_name)
+color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
+		       char const *no_color_label,
+		       ColorGroup *color_group)
 {
-	GdkImlibImage *image;
-
 	g_return_if_fail (cc != NULL);
 	g_return_if_fail (IS_COLOR_COMBO (cc));
 
@@ -174,27 +198,18 @@ color_combo_construct (ColorCombo *cc, char **icon,
 	 * Our button with the canvas preview
 	 */
 	cc->preview_button = gtk_button_new ();
-	if (!gnome_preferences_get_toolbar_relief_btn ())
-		gtk_button_set_relief (GTK_BUTTON (cc->preview_button), GTK_RELIEF_NONE);
+	gtk_button_set_relief (GTK_BUTTON (cc->preview_button), GTK_RELIEF_NONE);
 
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 	cc->preview_canvas = GNOME_CANVAS (gnome_canvas_new ());
-	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
 
 	gnome_canvas_set_scroll_region (cc->preview_canvas, 0, 0, 24, 24);
 	if (icon) {
-		image = gdk_imlib_create_image_from_xpm_data (icon);
-
 		gnome_canvas_item_new (
 			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
-			gnome_canvas_image_get_type (),
-			"image",  image,
+			GNOME_TYPE_CANVAS_PIXBUF,
+			"pixbuf", icon,
 			"x",      0.0,
 			"y",      0.0,
-			"width",  (double) image->rgb_width,
-			"height", (double) image->rgb_height,
 			"anchor", GTK_ANCHOR_NW,
 			NULL);
 		
@@ -228,7 +243,7 @@ color_combo_construct (ColorCombo *cc, char **icon,
 	/*
 	 * Our table selector
 	 */
-	color_table_setup (cc, no_color_label, group_name);
+	color_table_setup (cc, no_color_label, color_group);
 	
 	gtk_widget_show_all (cc->preview_button);
 	
@@ -236,20 +251,43 @@ color_combo_construct (ColorCombo *cc, char **icon,
 				 cc->preview_button,
 				 GTK_WIDGET (cc->palette));
 
-	if (!gnome_preferences_get_toolbar_relief_btn ())
-		gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (cc), GTK_RELIEF_NONE);
-
-	/* Start with the default color */
-	color_combo_set_color (cc, NULL);
+	/* Set our color to the current color on the palette */
+	color_combo_set_color_internal (cc, color_palette_get_current_color (cc->palette));
 }
 
-/*
- * Default constructor. Pass an XPM icon and an optional label for
- * the no/auto color button.
+/* color_combo_get_color:
+ *
+ * Return current color, result must be freed with gdk_color_free !
+ */
+GdkColor *
+color_combo_get_color (ColorCombo *cc)
+{
+	return color_palette_get_current_color (cc->palette);
+}
+
+void
+color_combo_set_color (ColorCombo *cc, GdkColor *color)
+{
+	/* This will change the color on the palette than
+	 * it will invoke cb_color_change which will call emit_change
+	 * and set_color_internal which will change the color on
+	 * our preview and will let the users of the combo know
+	 * that the current color has changed
+	 */
+	color_palette_set_current_color (cc->palette, color);
+}
+
+/**
+ * color_combo_new :
+ * icon : optionally NULL.
+ * , const char *no_color_label,
+ * Default constructor. Pass an optional icon and an optional label for the
+ * no/auto color button.
  */
 GtkWidget *
-color_combo_new (char **icon, const char *no_color_label,
-		 GdkColor *default_color, gchar *group_name)
+color_combo_new (GdkPixbuf *icon, char const *no_color_label,
+		 GdkColor *default_color,
+		 ColorGroup  *color_group)
 {
 	ColorCombo *cc;
 
@@ -257,7 +295,7 @@ color_combo_new (char **icon, const char *no_color_label,
 
         cc->default_color = default_color;
 
-	color_combo_construct (cc, icon, no_color_label, group_name);
+	color_combo_construct (cc, icon, no_color_label, color_group);
 
 	return GTK_WIDGET (cc);
 }
